@@ -7,10 +7,13 @@ from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 
+from trytond.modules.company.tests import CompanyTestMixin
 
-class ProjectRevenueTestCase(ModuleTestCase):
+
+class ProjectRevenueTestCase(CompanyTestMixin, ModuleTestCase):
     'Test ProjectRevenue module'
     module = 'project_revenue'
+    extras = ['purchase']
 
 
 def suite():
